pub trait TestExt {
    // Required methods
    fn new_ext() -> TestExternalities;
    fn reset_ext();
    fn execute_without_dispatch<R>(execute: impl FnOnce() -> R) -> R;
    fn dispatch_xcm_buses();

    // Provided method
    fn execute_with<R>(execute: impl FnOnce() -> R) -> R { ... }
}

Required Methods

source

fn new_ext() -> TestExternalities

Initialize the test environment.

source

fn reset_ext()

Resets the state of the test environment.

source

fn execute_without_dispatch<R>(execute: impl FnOnce() -> R) -> R

Execute code in the context of the test externalities, without automatic message processing. All messages in the message buses can be processed by calling Self::dispatch_xcm_buses().

source

fn dispatch_xcm_buses()

Process all messages in the message buses

Provided Methods

source

fn execute_with<R>(execute: impl FnOnce() -> R) -> R

Execute some code in the context of the test externalities, with automatic message processing. Messages are dispatched once the passed closure completes.

Implementors